import React$1, { ComponentProps, ReactNode, ForwardRefExoticComponent, ComponentPropsWithRef, ReactElement } from 'react';
import { SidebarItem, NormalizedSidebarGroup, SidebarDivider, NormalizedLocales, LocalSearchOptions, RemoteSearchOptions, Header, FrontMatterMeta, SocialLink } from '@rspress/shared';

interface UISwitchResult {
    showNavbar: boolean;
    showSidebar: boolean;
    showAside: boolean;
    showDocFooter: boolean;
}

interface DocLayoutProps {
    beforeSidebar?: React.ReactNode;
    afterSidebar?: React.ReactNode;
    beforeDocFooter?: React.ReactNode;
    afterDocFooter?: React.ReactNode;
    beforeDoc?: React.ReactNode;
    afterDoc?: React.ReactNode;
    beforeDocContent?: React.ReactNode;
    afterDocContent?: React.ReactNode;
    beforeOutline?: React.ReactNode;
    afterOutline?: React.ReactNode;
    uiSwitch?: UISwitchResult;
}
declare function DocLayout(props: DocLayoutProps): JSX.Element;

interface HomeLayoutProps {
    beforeHero?: React.ReactNode;
    afterHero?: React.ReactNode;
    beforeFeatures?: React.ReactNode;
    afterFeatures?: React.ReactNode;
}
declare function HomeLayout(props: HomeLayoutProps): JSX.Element;

interface NavProps {
    beforeNav?: React.ReactNode;
    beforeNavTitle?: React.ReactNode;
    afterNavTitle?: React.ReactNode;
    afterNavMenu?: React.ReactNode;
}
declare function Nav(props: NavProps): JSX.Element;

type LayoutProps = {
    top?: React$1.ReactNode;
    bottom?: React$1.ReactNode;
} & DocLayoutProps & HomeLayoutProps & NavProps;
declare const Layout: React$1.FC<LayoutProps>;

declare function NotFoundLayout(): JSX.Element;

declare function usePrevNextPage(): {
    prevPage: SidebarItem;
    nextPage: SidebarItem;
};

declare function useEditLink(): {
    text: string;
    link: string;
};

interface SidebarData {
    group: string;
    items: (NormalizedSidebarGroup | SidebarItem | SidebarDivider)[];
}
declare function useSidebarData(): SidebarData;

declare function useEnableNav(): readonly [boolean, React$1.Dispatch<React$1.SetStateAction<boolean>>];
declare function useHiddenNav(): boolean;

declare function useLocaleSiteData(): NormalizedLocales;

declare function scrollToTarget(target: HTMLElement, isSmooth: boolean, fallbackHeight?: number): void;
declare function bindingAsideScroll(): () => void;
declare function setup(): void;

declare function usePathUtils(): {
    normalizeLinkHref: (rawHref: string) => string;
};

declare function useFullTextSearch(): {
    initialized: boolean;
    search: (keyword: string, limit?: number) => Promise<MatchResult>;
};

/**
 * Redirect to current locale for first visit
 */
declare function useRedirect4FirstVisit(): void;

declare global {
    interface Window {
        MODERN_THEME?: string;
        RSPRESS_THEME?: string;
    }
}
type ThemeValue = 'light' | 'dark';
type ThemeConfigValue = ThemeValue | 'auto';
/**
 * State provider for theme context.
 */
declare const useThemeState: () => readonly [ThemeValue, (value: ThemeValue, storeValue?: ThemeConfigValue) => void];

declare function isActive(currentPath: string, targetLink?: string, strict?: boolean): boolean;
declare function isMobileDevice(): boolean;
declare function renderHtmlOrText(str?: string | number | null): React$1.ReactNode;
/**
 * In this method, we will render the markdown text to inline html and support basic markdown syntax, including the following:
 * - bold
 * - emphasis
 * - inline code
 * @param text The markdown text to render.
 */
declare function renderInlineMarkdown(text: string): React$1.ReactNode;
declare function parseInlineMarkdownText(mdx: string): string;

interface CodeProps {
    children: string;
    className?: string;
    codeHighlighter?: 'prism' | 'shiki';
    meta?: string;
}
declare function Code(props: CodeProps): JSX.Element;

declare function Pre({ children, }: {
    children: React.ReactElement[] | React.ReactElement;
}): JSX.Element;

declare function getCustomMDXComponent(): {
    h1: (props: React$1.DetailedHTMLProps<React$1.HTMLAttributes<HTMLHeadingElement>, HTMLHeadingElement>) => JSX.Element;
    h2: (props: React$1.DetailedHTMLProps<React$1.HTMLAttributes<HTMLHeadingElement>, HTMLHeadingElement>) => JSX.Element;
    h3: (props: React$1.DetailedHTMLProps<React$1.HTMLAttributes<HTMLHeadingElement>, HTMLHeadingElement>) => JSX.Element;
    h4: (props: React$1.DetailedHTMLProps<React$1.HTMLAttributes<HTMLHeadingElement>, HTMLHeadingElement>) => JSX.Element;
    h5: (props: React$1.DetailedHTMLProps<React$1.HTMLAttributes<HTMLHeadingElement>, HTMLHeadingElement>) => JSX.Element;
    h6: (props: React$1.DetailedHTMLProps<React$1.HTMLAttributes<HTMLHeadingElement>, HTMLHeadingElement>) => JSX.Element;
    ul: (props: React$1.DetailedHTMLProps<React$1.HTMLAttributes<HTMLUListElement>, HTMLUListElement>) => JSX.Element;
    ol: (props: React$1.DetailedHTMLProps<React$1.OlHTMLAttributes<HTMLOListElement>, HTMLOListElement>) => JSX.Element;
    li: (props: React$1.DetailedHTMLProps<React$1.LiHTMLAttributes<HTMLLIElement>, HTMLLIElement>) => JSX.Element;
    table: (props: React$1.DetailedHTMLProps<React$1.TableHTMLAttributes<HTMLTableElement>, HTMLTableElement>) => JSX.Element;
    td: (props: React$1.DetailedHTMLProps<React$1.TdHTMLAttributes<HTMLTableDataCellElement>, HTMLTableDataCellElement>) => JSX.Element;
    th: (props: React$1.DetailedHTMLProps<React$1.ThHTMLAttributes<HTMLTableHeaderCellElement>, HTMLTableHeaderCellElement>) => JSX.Element;
    tr: (props: React$1.DetailedHTMLProps<React$1.HTMLAttributes<HTMLTableRowElement>, HTMLTableRowElement>) => JSX.Element;
    hr: (props: React$1.DetailedHTMLProps<React$1.HTMLAttributes<HTMLHRElement>, HTMLHRElement>) => JSX.Element;
    p: (props: React$1.DetailedHTMLProps<React$1.HTMLAttributes<HTMLParagraphElement>, HTMLParagraphElement>) => JSX.Element;
    blockquote: (props: React$1.DetailedHTMLProps<React$1.BlockquoteHTMLAttributes<HTMLQuoteElement>, HTMLQuoteElement>) => JSX.Element;
    strong: (props: React$1.DetailedHTMLProps<React$1.HTMLAttributes<HTMLElement>, HTMLElement>) => JSX.Element;
    a: (props: React$1.DetailedHTMLProps<React$1.AnchorHTMLAttributes<HTMLAnchorElement>, HTMLAnchorElement>) => JSX.Element;
    code: typeof Code;
    pre: typeof Pre;
    img: (props: React$1.DetailedHTMLProps<React$1.ImgHTMLAttributes<HTMLImageElement>, HTMLImageElement>) => JSX.Element;
};

declare const enum RenderType {
    Default = "default",
    Custom = "custom"
}
interface HightlightInfo {
    start: number;
    length: number;
}
interface CommonMatchResult {
    title: string;
    header: string;
    link: string;
    query: string;
    highlightInfoList: HightlightInfo[];
    group: string;
}
interface TitleMatch extends CommonMatchResult {
    type: 'title';
}
interface HeaderMatch extends CommonMatchResult {
    type: 'header';
}
interface ContentMatch extends CommonMatchResult {
    type: 'content';
    statement: string;
}
type DefaultMatchResultItem = TitleMatch | HeaderMatch | ContentMatch;
type DefaultMatchResult = {
    group: string;
    renderType: RenderType;
    result: DefaultMatchResultItem[];
};
type UserMatchResultItem<T = unknown> = {
    group: string;
    result: T;
};
type CustomMatchResult = UserMatchResultItem & {
    renderType: RenderType.Custom;
};
type MatchResult = (DefaultMatchResult | CustomMatchResult)[];
type PageSearcherConfig = {
    currentLang: string;
    currentVersion: string;
    extractGroupName: (path: string) => string;
};
type SearchOptions = (LocalSearchOptions | RemoteSearchOptions) & PageSearcherConfig;
type BeforeSearch = (query: string) => string | Promise<string> | void;
type OnSearch = (query: string, matchedResult: DefaultMatchResult[]) => {
    group: string;
    result: unknown;
    renderType?: RenderType;
}[] | Promise<{
    group: string;
    result: unknown;
    renderType?: RenderType;
}[]> | void;
type AfterSearch = (query: string, matchedResult: MatchResult) => void | Promise<void>;
type RenderSearchFunction<T = unknown> = (result: T) => JSX.Element;

declare function Aside(props: {
    headers: Header[];
    outlineTitle: string;
}): JSX.Element;

interface BadgeProps {
    text: string;
    type: 'info' | 'warning' | 'danger';
}
declare function Badge(props: BadgeProps): JSX.Element;

interface ButtonProps {
    type?: string;
    size?: 'medium' | 'big';
    theme?: 'brand' | 'alt';
    text: string | React$1.ReactNode;
    href?: string;
    external?: boolean;
    className?: string;
}
declare function Button(props: ButtonProps): React$1.CElement<{
    className: string;
    href: string;
}, React$1.Component<{
    className: string;
    href: string;
}, any, any>>;

declare function DocFooter(): JSX.Element;

declare function EditLink(): JSX.Element;

declare function HomeFeature({ frontmatter }: {
    frontmatter: FrontMatterMeta;
}): JSX.Element;

declare function HomeFooter(): JSX.Element;

declare function HomeHero({ frontmatter }: {
    frontmatter: FrontMatterMeta;
}): JSX.Element;

declare function LastUpdated(): JSX.Element;

interface LinkProps extends ComponentProps<'a'> {
    href?: string;
    children?: React$1.ReactNode;
    className?: string;
    onNavigate?: () => void;
    keepCurrentParams?: boolean;
}
declare function Link(props: LinkProps): JSX.Element;

interface GroupItem {
    text?: string;
    link?: string;
    headers?: Header[];
}
interface Group {
    name: string;
    items: GroupItem[];
}
declare function Overview(props: {
    content?: React.ReactNode;
    groups?: Group[];
    defaultGroupTitle?: string;
    overviewHeaders?: number[];
}): JSX.Element;

interface PackageManagerTabProps {
    command: string | {
        npm?: string;
        yarn?: string;
        pnpm?: string;
        bun?: string;
    };
    additionalTabs?: {
        tool: string;
        icon?: React.ReactNode;
    }[];
}
declare function PackageManagerTabs({ command, additionalTabs, }: PackageManagerTabProps): JSX.Element;

interface PrevNextPageProps {
    type: 'prev' | 'next';
    text: string;
    href: string;
}
declare function PrevNextPage(props: PrevNextPageProps): JSX.Element;

declare function ScrollToTop(): JSX.Element;

interface SearchPanelProps {
    focused: boolean;
    setFocused: (focused: boolean) => void;
}
declare function SearchPanel({ focused, setFocused }: SearchPanelProps): JSX.Element;

declare function Search(): JSX.Element;

interface Props {
    isSidebarOpen?: boolean;
    beforeSidebar?: React$1.ReactNode;
    afterSidebar?: React$1.ReactNode;
    uiSwitch?: UISwitchResult;
}
declare function Sidebar(props: Props): JSX.Element;

declare const SocialLinks: ({ socialLinks }: {
    socialLinks: SocialLink[];
}) => JSX.Element;

interface SourceCodeProps {
    href: string;
    platform?: 'github' | 'gitlab';
}
declare function SourceCode(props: SourceCodeProps): JSX.Element;

declare function Steps({ children }: {
    children: ReactNode;
}): JSX.Element;

declare function SwitchAppearance({ onClick }: {
    onClick?: () => void;
}): JSX.Element;

type TabItem = {
    value?: string;
    label?: string | ReactNode;
    disabled?: boolean;
};
interface TabsProps {
    values: ReactNode[] | ReadonlyArray<ReactNode> | TabItem[];
    defaultValue?: string;
    onChange?: (index: number) => void;
    children: ReactNode;
    groupId?: string;
    tabContainerClassName?: string;
    tabPosition?: 'left' | 'center';
}
declare const Tabs: ForwardRefExoticComponent<TabsProps>;
declare function Tab({ children, ...props }: ComponentPropsWithRef<'div'>): ReactElement;

declare const Tag: ({ tag }: {
    tag?: string;
}) => JSX.Element;

declare function Toc({ onItemClick, }: {
    onItemClick?: (header: Header) => void;
}): JSX.Element;

declare const _default: {
    Layout: React$1.FC<LayoutProps>;
    NotFoundLayout: typeof NotFoundLayout;
    HomeLayout: typeof HomeLayout;
    setup: typeof setup;
};

export { type AfterSearch, Aside, Badge, type BeforeSearch, Button, type CustomMatchResult, type DefaultMatchResult, type DefaultMatchResultItem, DocFooter, DocLayout, EditLink, type HightlightInfo, HomeFeature, HomeFooter, HomeHero, HomeLayout, LastUpdated, Layout, Link, type MatchResult, Nav, NotFoundLayout, type OnSearch, Overview, PackageManagerTabs, type PageSearcherConfig, PrevNextPage, type RenderSearchFunction, RenderType, ScrollToTop, Search, type SearchOptions, SearchPanel, Sidebar, SocialLinks, SourceCode, Steps, SwitchAppearance, Tab, Tabs, Tag, Toc, type UserMatchResultItem, bindingAsideScroll, _default as default, getCustomMDXComponent, isActive, isMobileDevice, parseInlineMarkdownText, renderHtmlOrText, renderInlineMarkdown, scrollToTarget, setup, useEditLink, useEnableNav, useFullTextSearch, useHiddenNav, useLocaleSiteData, usePathUtils, usePrevNextPage, useRedirect4FirstVisit, useSidebarData, useThemeState };
